pub struct Deserializer<R> { /* private fields */ }Expand description
A structure for deserializing ROSMSG into Rust values.
The structure does not read the object size prefix. It’s the user’s responsibility to pass the expected object size themselves.
Prefer using from_reader, from_slice and from_str.
Implementations
Sourceimpl<R> Deserializer<R>where
R: Read,
impl<R> Deserializer<R>where
R: Read,
Sourcepub fn new(reader: R, expected_length: u32) -> Self
pub fn new(reader: R, expected_length: u32) -> Self
Create a new ROSMSG deserializer.
The value of expected_length tells the deserializer how long the data
that we want to read is.
Examples
use serde::de::Deserialize;
let data = b"\x0d\0\0\0Hello, World!\xAE";
let length = data.len();
let cursor = std::io::Cursor::new(&data);
let mut de = Deserializer::new(cursor, length as u32);
assert_eq!(String::deserialize(&mut de).unwrap(), "Hello, World!");
assert_eq!(u8::deserialize(&mut de).unwrap(), 0xAE);Sourcepub fn into_inner(self) -> R
pub fn into_inner(self) -> R
Unwrap the Reader from the Deserializer.
Examples
use serde::de::Deserialize;
let data = [2, 4, 8, 16];
let cursor = std::io::Cursor::new(&data);
let mut de = Deserializer::new(cursor, 2);
assert_eq!(u16::deserialize(&mut de).unwrap(), 1026);
let cursor_new = de.into_inner();
let mut de_new = Deserializer::new(cursor_new, 2);
assert_eq!(u16::deserialize(&mut de_new).unwrap(), 4104);Sourcepub fn is_fully_read(&self) -> bool
pub fn is_fully_read(&self) -> bool
Check if the deserializer is fully read.
If this is true, one cannot read from the deserializer anymore, and should use a different deserializer.
Examples
use serde::de::Deserialize;
let data = [2, 4, 8, 16];
let mut de = Deserializer::new(std::io::Cursor::new(&data), 4);
assert_eq!(de.is_fully_read(), false); // Still 4 bytes left to read
u16::deserialize(&mut de).unwrap(); // Read 2 bytes
assert_eq!(de.is_fully_read(), false); // Still 2 bytes left to read
u16::deserialize(&mut de).unwrap(); // Read 2 bytes
assert_eq!(de.is_fully_read(), true); // No more bytes left to read
u16::deserialize(&mut de).unwrap_err(); // Failure to read moreTrait Implementations
Sourceimpl<'de, 'a, R: Read> Deserializer<'de> for &'a mut Deserializer<R>
impl<'de, 'a, R: Read> Deserializer<'de> for &'a mut Deserializer<R>
Sourcetype Error = Error
type Error = Error
The error type that can be returned if some error occurs during
deserialization.
Sourcefn deserialize_any<V>(self, _visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_any<V>(self, _visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Require the
Deserializer to figure out how to drive the visitor based
on what data type is in the input. Read moreSourcefn deserialize_identifier<V>(self, _visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_identifier<V>(self, _visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting the name of a struct
field or the discriminant of an enum variant.Sourcefn deserialize_bool<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_bool<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a bool value.Sourcefn deserialize_u8<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_u8<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a u8 value.Sourcefn deserialize_i8<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_i8<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting an i8 value.Sourcefn deserialize_u16<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_u16<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a u16 value.Sourcefn deserialize_u32<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_u32<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a u32 value.Sourcefn deserialize_u64<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_u64<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a u64 value.Sourcefn deserialize_i16<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_i16<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting an i16 value.Sourcefn deserialize_i32<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_i32<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting an i32 value.Sourcefn deserialize_i64<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_i64<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting an i64 value.Sourcefn deserialize_f32<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_f32<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a f32 value.Sourcefn deserialize_f64<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_f64<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a f64 value.Sourcefn deserialize_char<V>(self, _visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_char<V>(self, _visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a char value.Sourcefn deserialize_str<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_str<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a string value and does
not benefit from taking ownership of buffered data owned by the
Deserializer. Read moreSourcefn deserialize_string<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_string<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a string value and would
benefit from taking ownership of buffered data owned by the
Deserializer. Read moreSourcefn deserialize_bytes<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_bytes<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a byte array and does not
benefit from taking ownership of buffered data owned by the
Deserializer. Read moreSourcefn deserialize_byte_buf<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_byte_buf<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a byte array and would
benefit from taking ownership of buffered data owned by the
Deserializer. Read moreSourcefn deserialize_option<V>(self, _visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_option<V>(self, _visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting an optional value. Read moreSourcefn deserialize_unit<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_unit<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a unit value.Sourcefn deserialize_unit_struct<V>(
self,
_name: &'static str,
visitor: V,
) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_unit_struct<V>(
self,
_name: &'static str,
visitor: V,
) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a unit struct with a
particular name.Sourcefn deserialize_newtype_struct<V>(
self,
_name: &'static str,
visitor: V,
) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_newtype_struct<V>(
self,
_name: &'static str,
visitor: V,
) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a newtype struct with a
particular name.Sourcefn deserialize_seq<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_seq<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a sequence of values.Sourcefn deserialize_tuple<V>(self, len: usize, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_tuple<V>(self, len: usize, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a sequence of values and
knows how many values there are without looking at the serialized data.Sourcefn deserialize_tuple_struct<V>(
self,
_name: &'static str,
len: usize,
visitor: V,
) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_tuple_struct<V>(
self,
_name: &'static str,
len: usize,
visitor: V,
) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a tuple struct with a
particular name and number of fields.Sourcefn deserialize_map<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_map<V>(self, visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a map of key-value pairs.Sourcefn deserialize_struct<V>(
self,
_name: &'static str,
fields: &'static [&'static str],
visitor: V,
) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_struct<V>(
self,
_name: &'static str,
fields: &'static [&'static str],
visitor: V,
) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting a struct with a particular
name and fields.Sourcefn deserialize_enum<V>(
self,
_name: &'static str,
_variants: &'static [&'static str],
_visitor: V,
) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_enum<V>(
self,
_name: &'static str,
_variants: &'static [&'static str],
_visitor: V,
) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type is expecting an enum value with a
particular name and possible variants.Sourcefn deserialize_ignored_any<V>(self, _visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
fn deserialize_ignored_any<V>(self, _visitor: V) -> Result<V::Value>where
V: Visitor<'de>,
Hint that the
Deserialize type needs to deserialize a value whose type
doesn’t matter because it is ignored. Read moreSourcefn deserialize_i128<V>(
self,
visitor: V,
) -> Result<<V as Visitor<'de>>::Value, Self::Error>where
V: Visitor<'de>,
fn deserialize_i128<V>(
self,
visitor: V,
) -> Result<<V as Visitor<'de>>::Value, Self::Error>where
V: Visitor<'de>,
Sourcefn deserialize_u128<V>(
self,
visitor: V,
) -> Result<<V as Visitor<'de>>::Value, Self::Error>where
V: Visitor<'de>,
fn deserialize_u128<V>(
self,
visitor: V,
) -> Result<<V as Visitor<'de>>::Value, Self::Error>where
V: Visitor<'de>,
Sourcefn is_human_readable(&self) -> bool
fn is_human_readable(&self) -> bool
Determine whether
Deserialize implementations should expect to
deserialize their human-readable form. Read moreAuto Trait Implementations
impl<R> Freeze for Deserializer<R>where
R: Freeze,
impl<R> RefUnwindSafe for Deserializer<R>where
R: RefUnwindSafe,
impl<R> Send for Deserializer<R>where
R: Send,
impl<R> Sync for Deserializer<R>where
R: Sync,
impl<R> Unpin for Deserializer<R>where
R: Unpin,
impl<R> UnwindSafe for Deserializer<R>where
R: UnwindSafe,